==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/expression/impl/SelectRelatedSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.classes.SelectorSet;
import io.ciera.tool.sql.architecture.classes.impl.SelectorSetImpl;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.SelectRelated;
import io.ciera.tool.sql.architecture.expression.SelectRelatedSet;
import io.ciera.tool.sql.architecture.expression.SelectSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;
import io.ciera.tool.sql.architecture.expression.impl.SelectSetImpl;

import java.util.Arrays;
import java.util.List;


public class SelectRelatedSetImpl extends InstanceSet<SelectRelatedSet,SelectRelated> implements SelectRelatedSet {

    // attributes
    @Override
    public void setSelector_parent_name( String ref_selector_parent_name ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setSelector_parent_name( ref_selector_parent_name );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setExpression_number( ref_expression_number );
    }
    @Override
    public void setSelector_name( String ref_selector_name ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setSelector_name( ref_selector_name );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setParent_name( ref_parent_name );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setBody_name( ref_body_name );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setStatement_number( ref_statement_number );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setBlock_number( ref_block_number );
    }
    @Override
    public void setSelector_parent_package( String ref_selector_parent_package ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setSelector_parent_package( ref_selector_parent_package );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setParent_package( ref_parent_package );
    }
    @Override
    public void setRoot_expression_number( String ref_root_expression_number ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setRoot_expression_number( ref_root_expression_number );
    }


    // selections
    @Override
    public SelectSet R789_is_a_Select() throws XtumlException {
        SelectSet selectset = new SelectSetImpl();
        for ( SelectRelated selectrelated : this ) selectset.add( selectrelated.R789_is_a_Select() );
        return selectset;
    }
    @Override
    public ExpressionSet R791_selects_instances_linked_from_instance_expressed_by_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( SelectRelated selectrelated : this ) expressionset.add( selectrelated.R791_selects_instances_linked_from_instance_expressed_by_Expression() );
        return expressionset;
    }
    @Override
    public SelectorSet R797_selects_instances_through_Selector() throws XtumlException {
        SelectorSet selectorset = new SelectorSetImpl();
        for ( SelectRelated selectrelated : this ) selectorset.add( selectrelated.R797_selects_instances_through_Selector() );
        return selectorset;
    }


    @Override
    public SelectRelated nullElement() {
        return SelectRelatedImpl.EMPTY_SELECTRELATED;
    }

    @Override
    public SelectRelatedSet emptySet() {
      return new SelectRelatedSetImpl();
    }

    @Override
    public SelectRelatedSet value() {
        return this;
    }

    @Override
    public List<SelectRelated> elements() {
        return Arrays.asList(toArray(new SelectRelated[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/expression/impl/SelectRelatedSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.classes.SelectorSet;
import io.ciera.tool.sql.architecture.classes.impl.SelectorSetImpl;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.SelectRelated;
import io.ciera.tool.sql.architecture.expression.SelectRelatedSet;
import io.ciera.tool.sql.architecture.expression.SelectSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;
import io.ciera.tool.sql.architecture.expression.impl.SelectSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SelectRelatedSetImpl extends InstanceSet<SelectRelatedSet,SelectRelated> implements SelectRelatedSet {

    public SelectRelatedSetImpl() {
    }

    public SelectRelatedSetImpl(Comparator<? super SelectRelated> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setExpression_number( ref_expression_number );
    }
    @Override
    public void setSelector_name( String ref_selector_name ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setSelector_name( ref_selector_name );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setBody_name( ref_body_name );
    }
    @Override
    public void setRoot_expression_number( String ref_root_expression_number ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setRoot_expression_number( ref_root_expression_number );
    }
    @Override
    public void setSelector_parent_package( String ref_selector_parent_package ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setSelector_parent_package( ref_selector_parent_package );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setParent_name( ref_parent_name );
    }
    @Override
    public void setSelector_parent_name( String ref_selector_parent_name ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setSelector_parent_name( ref_selector_parent_name );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setParent_package( ref_parent_package );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setBlock_number( ref_block_number );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( SelectRelated selectrelated : this ) selectrelated.setStatement_number( ref_statement_number );
    }


    // selections
    @Override
    public SelectSet R789_is_a_Select() throws XtumlException {
        SelectSet selectset = new SelectSetImpl();
        for ( SelectRelated selectrelated : this ) selectset.add( selectrelated.R789_is_a_Select() );
        return selectset;
    }
    @Override
    public ExpressionSet R791_selects_instances_linked_from_instance_expressed_by_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( SelectRelated selectrelated : this ) expressionset.add( selectrelated.R791_selects_instances_linked_from_instance_expressed_by_Expression() );
        return expressionset;
    }
    @Override
    public SelectorSet R797_selects_instances_through_Selector() throws XtumlException {
        SelectorSet selectorset = new SelectorSetImpl();
        for ( SelectRelated selectrelated : this ) selectorset.add( selectrelated.R797_selects_instances_through_Selector() );
        return selectorset;
    }


    @Override
    public SelectRelated nullElement() {
        return SelectRelatedImpl.EMPTY_SELECTRELATED;
    }

    @Override
    public SelectRelatedSet emptySet() {
      return new SelectRelatedSetImpl();
    }

    @Override
    public SelectRelatedSet emptySet(Comparator<? super SelectRelated> comp) {
      return new SelectRelatedSetImpl(comp);
    }

    @Override
    public SelectRelatedSet value() {
        return this;
    }

    @Override
    public List<SelectRelated> elements() {
        return Arrays.asList(toArray(new SelectRelated[0]));
    }

}
